@@ -16,17 +16,21 @@
 #include <gtk/gtk.h>
 #include <math.h>
 
-#define BACKGROUND_NAME "/pixbufs/background.jpg"
+#include "demo-common.h"
+
+#define FRAME_DELAY 50
+
+#define BACKGROUND_NAME "background.jpg"
 
 static const char *image_names[] = {
-  "/pixbufs/apple-red.png",
-  "/pixbufs/gnome-applets.png",
-  "/pixbufs/gnome-calendar.png",
-  "/pixbufs/gnome-foot.png",
-  "/pixbufs/gnome-gmush.png",
-  "/pixbufs/gnome-gimp.png",
-  "/pixbufs/gnome-gsame.png",
-  "/pixbufs/gnu-keys.png"
+  "apple-red.png",
+  "gnome-applets.png",
+  "gnome-calendar.png",
+  "gnome-foot.png",
+  "gnome-gmush.png",
+  "gnome-gimp.png",
+  "gnome-gsame.png",
+  "gnu-keys.png"
 };
 
 #define N_IMAGES G_N_ELEMENTS (image_names)
@@ -52,11 +56,22 @@ static gboolean
 load_pixbufs (GError **error)
 {
   gint i;
+  char *filename;
 
   if (background)
     return TRUE; /* already loaded earlier */
 
-  background = gdk_pixbuf_new_from_resource (BACKGROUND_NAME, error);
+  /* demo_find_file() looks in the current directory first,
+   * so you can run gtk-demo without installing GTK, then looks
+   * in the location where the file is installed.
+   */
+  filename = demo_find_file (BACKGROUND_NAME, error);
+  if (!filename)
+    return FALSE; /* note that "error" was filled in and returned */
+
+  background = gdk_pixbuf_new_from_file (filename, error);
+  g_free (filename);
+
   if (!background)
     return FALSE; /* Note that "error" was filled with a GError */
 
@@ -65,7 +80,12 @@ load_pixbufs (GError **error)
 
   for (i = 0; i < N_IMAGES; i++)
     {
-      images[i] = gdk_pixbuf_new_from_resource (image_names[i], error);
+      filename = demo_find_file (image_names[i], error);
+      if (!filename)
+        return FALSE; /* Note that "error" was filled with a GError */
+
+      images[i] = gdk_pixbuf_new_from_file (filename, error);
+      g_free (filename);
 
       if (!images[i])
         return FALSE; /* Note that "error" was filled with a GError */
@@ -86,17 +106,14 @@ draw_cb (GtkWidget *widget,
   return TRUE;
 }
 
-#define CYCLE_TIME 3000000 /* 3 seconds */
+#define CYCLE_LEN 60
 
-static gint64 start_time;
+static int frame_num;
 
-/* Handler to regenerate the frame */
-static gboolean
-on_tick (GtkWidget     *widget,
-         GdkFrameClock *frame_clock,
-         gpointer       data)
+/* Timeout handler to regenerate the frame */
+static gint
+timeout (gpointer data)
 {
-  gint64 current_time;
   double f;
   int i;
   double xmid, ymid;
@@ -105,11 +122,7 @@ on_tick (GtkWidget     *widget,
   gdk_pixbuf_copy_area (background, 0, 0, back_width, back_height,
                         frame, 0, 0);
 
-  if (start_time == 0)
-    start_time = gdk_frame_clock_get_frame_time (frame_clock);
-
-  current_time = gdk_frame_clock_get_frame_time (frame_clock);
-  f = ((current_time - start_time) % CYCLE_TIME) / (double)CYCLE_TIME;
+  f = (double) (frame_num % CYCLE_LEN) / CYCLE_LEN;
 
   xmid = back_width / 2.0;
   ymid = back_height / 2.0;
@@ -162,11 +175,24 @@ on_tick (GtkWidget     *widget,
                                : MAX (127, fabs (255 * cos (f * 2.0 * G_PI)))));
     }
 
+  GDK_THREADS_ENTER ();
   gtk_widget_queue_draw (da);
+  GDK_THREADS_LEAVE ();
 
+  frame_num++;
   return G_SOURCE_CONTINUE;
 }
 
+static guint timeout_id;
+
+static void
+cleanup_callback (GObject   *object,
+                  gpointer   data)
+{
+  g_source_remove (timeout_id);
+  timeout_id = 0;
+}
+
 GtkWidget *
 do_pixbufs (GtkWidget *do_widget)
 {
@@ -182,6 +208,8 @@ do_pixbufs (GtkWidget *do_widget)
 
       g_signal_connect (window, "destroy",
                         G_CALLBACK (gtk_widget_destroyed), &window);
+      g_signal_connect (window, "destroy",
+                        G_CALLBACK (cleanup_callback), NULL);
 
 
       error = NULL;
@@ -216,7 +244,7 @@ do_pixbufs (GtkWidget *do_widget)
 
           gtk_container_add (GTK_CONTAINER (window), da);
 
-          gtk_widget_add_tick_callback (da, on_tick, NULL, NULL);
+          timeout_id = g_timeout_add (FRAME_DELAY, timeout, NULL);
         }
     }
 
