@@ -24,6 +24,7 @@
 
 #include "gdkpixbuf.h"
 
+#include "gdkcolor.h"
 #include "gdkwindow.h"
 #include "gdkinternals.h"
 
@@ -56,29 +57,28 @@
  * This allows you to efficiently read individual pixels on the client side.
  *
  * This function will create an RGB pixbuf with 8 bits per channel with
- * the size specified by the @width and @height arguments scaled by the
- * scale factor of @window. The pixbuf will contain an alpha channel if
- * the @window contains one.
+ * the same size specified by the @width and @height arguments. The pixbuf
+ * will contain an alpha channel if the @window contains one.
  *
  * If the window is off the screen, then there is no image data in the
  * obscured/offscreen regions to be placed in the pixbuf. The contents of
  * portions of the pixbuf corresponding to the offscreen region are undefined.
  *
- * If the window you’re obtaining data from is partially obscured by
+ * If the window you're obtaining data from is partially obscured by
  * other windows, then the contents of the pixbuf areas corresponding
  * to the obscured regions are undefined.
  *
- * If the window is not mapped (typically because it’s iconified/minimized
+ * If the window is not mapped (typically because it's iconified/minimized
  * or not on the current workspace), then %NULL will be returned.
  *
- * If memory can’t be allocated for the return value, %NULL will be returned
+ * If memory can't be allocated for the return value, %NULL will be returned
  * instead.
  *
  * (In short, there are several ways this function can fail, and if it fails
  *  it returns %NULL; so check the return value.)
  *
- * Returns: (nullable) (transfer full): A newly-created pixbuf with a
- *     reference count of 1, or %NULL on error
+ * Return value: (transfer full): A newly-created pixbuf with a reference
+ *     count of 1, or %NULL on error
  */
 GdkPixbuf *
 gdk_pixbuf_get_from_window (GdkWindow *src,
@@ -88,49 +88,15 @@ gdk_pixbuf_get_from_window (GdkWindow *src,
                             gint       height)
 {
   cairo_surface_t *surface;
-  cairo_surface_t *copy;
-  cairo_t *cr;
   GdkPixbuf *dest;
-  int scale;
 
   g_return_val_if_fail (GDK_IS_WINDOW (src), NULL);
   g_return_val_if_fail (gdk_window_is_viewable (src), NULL);
 
   surface = _gdk_window_ref_cairo_surface (src);
-  scale = gdk_window_get_scale_factor (src);
-
-  /* We do not know what happened to this surface outside of GDK.
-   * Especially for foreign windows, they will have been modified
-   * by external applications.
-   *
-   * So be on the safe side and:
-   * - mark the surface as dirty, in case the GdkWindow was
-   *   created from a foreign X11 surface
-   * - flush the Cairo state
-   *
-   * For reference, see:
-   * - https://bugzilla.gnome.org/show_bug.cgi?id=754952
-   * - https://gitlab.gnome.org/GNOME/gtk/-/issues/4456
-   */
-  cairo_surface_mark_dirty (surface);
-  cairo_surface_flush (surface);
-
-  if (cairo_surface_get_content (surface) & CAIRO_CONTENT_ALPHA)
-    copy = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, width * scale, height * scale);
-  else
-    copy = cairo_image_surface_create (CAIRO_FORMAT_RGB24, width * scale, height * scale);
-
-  cairo_surface_set_device_scale (copy, scale, scale);
-
-  cr = cairo_create (copy);
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  cairo_set_source_surface (cr, surface, -src_x, -src_y);
-  cairo_paint (cr);
-  cairo_destroy (cr);
-
-  dest = gdk_pixbuf_get_from_surface (copy, 0, 0, width * scale, height * scale);
-
-  cairo_surface_destroy (copy);
+  dest = gdk_pixbuf_get_from_surface (surface,
+                                      src_x, src_y,
+                                      width, height);
   cairo_surface_destroy (surface);
 
   return dest;
@@ -259,8 +225,8 @@ convert_no_alpha (guchar *dest_data,
  * This function will create an RGB pixbuf with 8 bits per channel.
  * The pixbuf will contain an alpha channel if the @surface contains one.
  *
- * Returns: (nullable) (transfer full): A newly-created pixbuf with a
- *     reference count of 1, or %NULL on error
+ * Return value: (transfer full): A newly-created pixbuf with a reference
+ *     count of 1, or %NULL on error
  */
 GdkPixbuf *
 gdk_pixbuf_get_from_surface  (cairo_surface_t *surface,
@@ -282,22 +248,13 @@ gdk_pixbuf_get_from_surface  (cairo_surface_t *surface,
                          8,
                          width, height);
 
-  if (cairo_surface_get_type (surface) == CAIRO_SURFACE_TYPE_IMAGE &&
-      cairo_image_surface_get_format (surface) == gdk_cairo_format_for_content (content))
-    surface = cairo_surface_reference (surface);
-  else
-    {
-      surface = gdk_cairo_surface_coerce_to_image (surface, content,
-						   src_x, src_y,
-						   width, height);
-      src_x = 0;
-      src_y = 0;
-    }
+  surface = gdk_cairo_surface_coerce_to_image (surface, content,
+                                               src_x, src_y,
+                                               width, height);
   cairo_surface_flush (surface);
   if (cairo_surface_status (surface) || dest == NULL)
     {
       cairo_surface_destroy (surface);
-      g_clear_object (&dest);
       return NULL;
     }
 
@@ -306,14 +263,14 @@ gdk_pixbuf_get_from_surface  (cairo_surface_t *surface,
                    gdk_pixbuf_get_rowstride (dest),
                    cairo_image_surface_get_data (surface),
                    cairo_image_surface_get_stride (surface),
-                   src_x, src_y,
+                   0, 0,
                    width, height);
   else
     convert_no_alpha (gdk_pixbuf_get_pixels (dest),
                       gdk_pixbuf_get_rowstride (dest),
                       cairo_image_surface_get_data (surface),
                       cairo_image_surface_get_stride (surface),
-                      src_x, src_y,
+                      0, 0,
                       width, height);
 
   cairo_surface_destroy (surface);
