@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -360,9 +358,10 @@ print_cursor (int index)
 }
 #endif
 
-static void
-_gdk_input_wintab_init_check (GdkDeviceManagerWin32 *device_manager)
+void
+_gdk_input_wintab_init_check (GdkDeviceManager *_device_manager)
 {
+  GdkDeviceManagerWin32 *device_manager = (GdkDeviceManagerWin32 *)_device_manager;
   static gboolean wintab_initialized = FALSE;
   GdkDeviceWintab *device;
   GdkWindowAttr wa;
@@ -577,8 +576,8 @@ _gdk_input_wintab_init_check (GdkDeviceManagerWin32 *device_manager)
           device = g_object_new (GDK_TYPE_DEVICE_WINTAB,
                                  "name", device_name,
                                  "type", GDK_DEVICE_TYPE_SLAVE,
-                                 "source", GDK_SOURCE_PEN,
-                                 "mode", GDK_MODE_SCREEN,
+                                 "input-source", GDK_SOURCE_PEN,
+                                 "input-mode", GDK_MODE_SCREEN,
                                  "has-cursor", FALSE,
                                  "display", _gdk_display,
                                  "device-manager", device_manager,
@@ -690,8 +689,6 @@ gdk_device_manager_win32_constructed (GObject *object)
 
   _gdk_device_set_associated_device (device_manager->core_pointer, device_manager->core_keyboard);
   _gdk_device_set_associated_device (device_manager->core_keyboard, device_manager->core_pointer);
-
-  _gdk_input_wintab_init_check (device_manager);
 }
 
 static GList *
