@@ -32,7 +32,7 @@
  *
  * The scale settings are used to specify how much the child widget should
  * expand to fill the space allocated to the #GtkAlignment.
- * The values can range from 0 (meaning the child doesn’t expand at all) to
+ * The values can range from 0 (meaning the child doesn't expand at all) to
  * 1 (meaning the child expands to fill all of the available space).
  *
  * The align settings are used to place the child widget within the available
@@ -40,9 +40,13 @@
  * Of course, if the scale settings are both set to 1, the alignment settings
  * have no effect.
  *
+ * <note>
+ * <para>
  * Note that the desired effect can in most cases be achieved by using the
  * #GtkWidget:halign, #GtkWidget:valign and #GtkWidget:margin properties
  * on the child widget, so #GtkAlignment should not be used in new code.
+ * </para>
+ * </note>
  */
 
 #include "config.h"
@@ -104,14 +108,8 @@ static void gtk_alignment_get_preferred_height_for_width (GtkWidget           *w
 							  gint                 for_size,
 							  gint                *minimum_size,
 							  gint                *natural_size);
-static void gtk_alignment_get_preferred_height_and_baseline_for_width (GtkWidget           *widget,
-								       gint                 for_size,
-								       gint                *minimum_size,
-								       gint                *natural_size,
-								       gint                *minimum_baseline,
-								       gint                *natural_baseline);
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtkAlignment, gtk_alignment, GTK_TYPE_BIN)
+G_DEFINE_TYPE (GtkAlignment, gtk_alignment, GTK_TYPE_BIN)
 
 static void
 gtk_alignment_class_init (GtkAlignmentClass *class)
@@ -130,7 +128,6 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
   widget_class->get_preferred_height = gtk_alignment_get_preferred_height;
   widget_class->get_preferred_width_for_height = gtk_alignment_get_preferred_width_for_height;
   widget_class->get_preferred_height_for_width = gtk_alignment_get_preferred_height_for_width;
-  widget_class->get_preferred_height_and_baseline_for_width = gtk_alignment_get_preferred_height_and_baseline_for_width;
 
   g_object_class_install_property (gobject_class,
                                    PROP_XALIGN,
@@ -238,6 +235,8 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       G_MAXINT,
                                                       0,
                                                       GTK_PARAM_READWRITE));
+
+  g_type_class_add_private (gobject_class, sizeof (GtkAlignmentPrivate));
 }
 
 static void
@@ -245,7 +244,9 @@ gtk_alignment_init (GtkAlignment *alignment)
 {
   GtkAlignmentPrivate *priv;
 
-  alignment->priv = gtk_alignment_get_instance_private (alignment);
+  alignment->priv = G_TYPE_INSTANCE_GET_PRIVATE (alignment,
+                                                 GTK_TYPE_ALIGNMENT,
+                                                 GtkAlignmentPrivate);
   priv = alignment->priv;
 
   gtk_widget_set_has_window (GTK_WIDGET (alignment), FALSE);
@@ -504,8 +505,11 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   GtkAllocation child_allocation;
   GtkWidget *child;
   gint width, height;
-  gint border_width;
-  gint baseline;
+  guint border_width;
+  gint padding_horizontal, padding_vertical;
+
+  padding_horizontal = 0;
+  padding_vertical = 0;
 
   gtk_widget_set_allocation (widget, allocation);
   bin = GTK_BIN (widget);
@@ -513,11 +517,9 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
   child = gtk_bin_get_child (bin);
   if (child && gtk_widget_get_visible (child))
     {
-      gint padding_horizontal, padding_vertical;
       gint child_nat_width;
       gint child_nat_height;
       gint child_width, child_height;
-      double yalign, yscale;
 
       border_width = gtk_container_get_border_width (GTK_CONTAINER (alignment));
 
@@ -527,25 +529,6 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
       width  = MAX (1, allocation->width - padding_horizontal - 2 * border_width);
       height = MAX (1, allocation->height - padding_vertical - 2 * border_width);
 
-      baseline = gtk_widget_get_allocated_baseline (widget);
-      if (baseline != -1)
-	baseline -= border_width + priv->padding_top;
-
-      /* If we get a baseline set that means we're baseline aligned, and the parent
-	 honored that. In that case we have to ignore yalign/yscale as we need
-	 yalign based on the baseline and always FILL mode to ensure we can place
-	 the baseline anywhere */
-      if (baseline != -1)
-	{
-	  yalign = 0;
-	  yscale = 1.0;
-	}
-      else
-	{
-	  yalign = priv->yalign;
-	  yscale = priv->yscale;
-	}
-
       if (gtk_widget_get_request_mode (child) == GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH)
 	{
 	  gtk_widget_get_preferred_width (child, NULL, &child_nat_width);
@@ -576,8 +559,8 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
 
       if (height > child_height)
 	child_allocation.height = (child_height *
-				   (1.0 - yscale) +
-				   height * yscale);
+				   (1.0 - priv->yscale) +
+				   height * priv->yscale);
       else
 	child_allocation.height = height;
 
@@ -586,9 +569,9 @@ gtk_alignment_size_allocate (GtkWidget     *widget,
       else 
 	child_allocation.x = priv->xalign * (width - child_allocation.width) + allocation->x + border_width + priv->padding_left;
 
-      child_allocation.y = yalign * (height - child_allocation.height) + allocation->y + border_width + priv->padding_top;
+      child_allocation.y = priv->yalign * (height - child_allocation.height) + allocation->y + border_width + priv->padding_top;
 
-      gtk_widget_size_allocate_with_baseline (child, &child_allocation, baseline);
+      gtk_widget_size_allocate (child, &child_allocation);
     }
 }
 
@@ -598,30 +581,18 @@ gtk_alignment_get_preferred_size (GtkWidget      *widget,
                                   GtkOrientation  orientation,
 				  gint            for_size,
                                   gint           *minimum_size,
-                                  gint           *natural_size,
-                                  gint           *minimum_baseline,
-                                  gint           *natural_baseline)
+                                  gint           *natural_size)
 {
   GtkAlignment *alignment = GTK_ALIGNMENT (widget);
   GtkAlignmentPrivate *priv = alignment->priv;
   GtkWidget *child;
   guint minimum, natural;
-  guint top_offset;
-  guint border;
 
-  if (minimum_baseline)
-    *minimum_baseline = -1;
-  if (natural_baseline)
-    *natural_baseline = -1;
-
-  border = gtk_container_get_border_width (GTK_CONTAINER (widget));
-  natural = minimum = border * 2;
-  top_offset = border;
+  natural = minimum = gtk_container_get_border_width (GTK_CONTAINER (widget)) * 2;
 
   if ((child = gtk_bin_get_child (GTK_BIN (widget))) && gtk_widget_get_visible (child))
     {
       gint child_min, child_nat;
-      gint child_min_baseline = -1, child_nat_baseline = -1;
 
       /* Request extra space for the padding: */
       if (orientation == GTK_ORIENTATION_HORIZONTAL)
@@ -648,10 +619,9 @@ gtk_alignment_get_preferred_size (GtkWidget      *widget,
       else
 	{
 	  minimum += (priv->padding_top + priv->padding_bottom);
-	  top_offset += priv->padding_top;
 
 	  if (for_size < 0)
-	    gtk_widget_get_preferred_height_and_baseline_for_width (child, -1, &child_min, &child_nat, &child_min_baseline, &child_nat_baseline);
+	    gtk_widget_get_preferred_height (child, &child_min, &child_nat);
 	  else
 	    {
 	      gint min_width;
@@ -664,13 +634,8 @@ gtk_alignment_get_preferred_size (GtkWidget      *widget,
 		for_size = (min_width * (1.0 - priv->xscale) +
 			    for_size * priv->xscale);
 
-	      gtk_widget_get_preferred_height_and_baseline_for_width (child, for_size, &child_min, &child_nat, &child_min_baseline, &child_nat_baseline);
+	      gtk_widget_get_preferred_height_for_width (child, for_size, &child_min, &child_nat);
 	    }
-
-	  if (minimum_baseline && child_min_baseline >= 0)
-	    *minimum_baseline = child_min_baseline + top_offset;
-	  if (natural_baseline && child_nat_baseline >= 0)
-	    *natural_baseline = child_nat_baseline + top_offset;
 	}
 
       natural = minimum;
@@ -691,7 +656,7 @@ gtk_alignment_get_preferred_width (GtkWidget      *widget,
                                    gint           *minimum_size,
                                    gint           *natural_size)
 {
-  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_HORIZONTAL, -1, minimum_size, natural_size, NULL, NULL);
+  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_HORIZONTAL, -1, minimum_size, natural_size);
 }
 
 static void
@@ -699,7 +664,7 @@ gtk_alignment_get_preferred_height (GtkWidget      *widget,
                                     gint           *minimum_size,
                                     gint           *natural_size)
 {
-  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_VERTICAL, -1, minimum_size, natural_size, NULL, NULL);
+  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_VERTICAL, -1, minimum_size, natural_size);
 }
 
 
@@ -709,7 +674,7 @@ gtk_alignment_get_preferred_width_for_height (GtkWidget           *widget,
 					      gint                *minimum_size,
 					      gint                *natural_size)
 {
-  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_HORIZONTAL, for_size, minimum_size, natural_size, NULL, NULL);
+  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_HORIZONTAL, for_size, minimum_size, natural_size);
 }
 
 static void
@@ -718,21 +683,9 @@ gtk_alignment_get_preferred_height_for_width (GtkWidget           *widget,
 					      gint                *minimum_size,
 					      gint                *natural_size)
 {
-  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_VERTICAL, for_size, minimum_size, natural_size, NULL, NULL);
+  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_VERTICAL, for_size, minimum_size, natural_size);
 }
 
-static void
-gtk_alignment_get_preferred_height_and_baseline_for_width (GtkWidget           *widget,
-							   gint                 for_size,
-							   gint                *minimum_size,
-							   gint                *natural_size,
-							   gint                *minimum_baseline,
-							   gint                *natural_baseline)
-{
-  gtk_alignment_get_preferred_size (widget, GTK_ORIENTATION_VERTICAL, for_size, minimum_size, natural_size, minimum_baseline, natural_baseline);
-}
-
-
 /**
  * gtk_alignment_set_padding:
  * @alignment: a #GtkAlignment
