@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -28,7 +26,7 @@
  * SECTION:gtkbox
  * @Short_description: A container box
  * @Title: GtkBox
- * @See_also: #GtkFrame, #GtkTable, #GtkLayout
+ * @See_also: #GtkFrame, #GtkGrid, #GtkLayout
  *
  * The GtkBox widget organizes child widgets into a rectangular area.
  *
@@ -80,11 +78,13 @@
 #include "config.h"
 
 #include "gtkbox.h"
-#include "gtkorientable.h"
-#include "gtksizerequest.h"
-#include "gtktypebuiltins.h"
-#include "gtkprivate.h"
+#include "gtkboxprivate.h"
 #include "gtkintl.h"
+#include "gtkorientable.h"
+#include "gtkprivate.h"
+#include "gtktypebuiltins.h"
+#include "gtksizerequest.h"
+#include "gtkwidgetpath.h"
 #include "a11y/gtkboxaccessible.h"
 
 
@@ -861,18 +861,24 @@ count_widget_position (GtkWidget *widget,
     count->before++;
 }
 
-static guint
-gtk_box_get_visible_position (GtkBox *box,
+static gint
+gtk_box_get_visible_position (GtkBox    *box,
                               GtkWidget *child)
 {
   CountingData count = { child, FALSE, 0, 0 };
 
-  /* forall iterates in visible order */
-  gtk_container_forall (GTK_CONTAINER (box),
-                        count_widget_position,
-                        &count);
+  /* foreach iterates in visible order */
+  gtk_container_foreach (GTK_CONTAINER (box),
+                         count_widget_position,
+                         &count);
+
+  /* the child wasn't found, it's likely an internal child of some
+   * subclass, return -1 to indicate that there is no sibling relation
+   * to the regular box children
+   */
+  if (!count.found)
+    return -1;
 
-  g_assert (count.found);
   if (box->priv->orientation == GTK_ORIENTATION_HORIZONTAL &&
       gtk_widget_get_direction (GTK_WIDGET (box)) == GTK_TEXT_DIR_RTL)
     return count.after;
@@ -896,6 +902,8 @@ gtk_box_get_path_for_child (GtkContainer *container,
 
   if (gtk_widget_get_visible (child))
     {
+      gint position;
+
       sibling_path = gtk_widget_path_new ();
 
       /* get_children works in visible order */
@@ -911,13 +919,17 @@ gtk_box_get_path_for_child (GtkContainer *container,
 
           gtk_widget_path_append_for_widget (sibling_path, list->data);
         }
-        g_list_free (children);
 
-        gtk_widget_path_append_with_siblings (path,
-                                              sibling_path,
-                                              gtk_box_get_visible_position (box,
-                                                                            child));
-        gtk_widget_path_unref (sibling_path);
+      g_list_free (children);
+
+      position = gtk_box_get_visible_position (box, child);
+
+      if (position >= 0)
+        gtk_widget_path_append_with_siblings (path, sibling_path, position);
+      else
+        gtk_widget_path_append_for_widget (path, child);
+
+      gtk_widget_path_unref (sibling_path);
     }
   else
     gtk_widget_path_append_for_widget (path, child);
@@ -1796,13 +1808,13 @@ gtk_box_remove (GtkContainer *container,
 	{
 	  gboolean was_visible;
 
-	  was_visible = gtk_widget_get_visible (widget);
-	  gtk_widget_unparent (widget);
-
           g_signal_handlers_disconnect_by_func (widget,
                                                 box_child_visibility_notify_cb,
                                                 box);
 
+	  was_visible = gtk_widget_get_visible (widget);
+	  gtk_widget_unparent (widget);
+
 	  priv->children = g_list_remove_link (priv->children, children);
 	  g_list_free (children);
 	  g_free (child);
