@@ -26,8 +26,6 @@
 #define __GTK_MENU_PRIVATE_H__
 
 #include <gtk/gtkmenu.h>
-#include <gtk/gtkcssgadgetprivate.h>
-#include <gtk/gtkcssnodeprivate.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +36,13 @@ typedef enum
   GTK_DIRECTION_RIGHT
 } GtkSubmenuDirection;
 
+/* Placement of submenus */
+typedef enum
+{
+  GTK_TOP_BOTTOM,
+  GTK_LEFT_RIGHT
+} GtkSubmenuPlacement;
+
 
 struct _GtkMenuPrivate
 {
@@ -45,7 +50,7 @@ struct _GtkMenuPrivate
   GtkWidget *old_active_menu_item;
 
   GtkAccelGroup *accel_group;
-  const char    *accel_path;
+  gchar         *accel_path;
 
   GtkMenuPositionFunc position_func;
   gpointer            position_func_data;
@@ -53,17 +58,6 @@ struct _GtkMenuPrivate
   gint                position_x;
   gint                position_y;
 
-  GdkWindow         *rect_window;
-  GdkRectangle       rect;
-  GtkWidget         *widget;
-  GdkGravity         rect_anchor;
-  GdkGravity         menu_anchor;
-  GdkAnchorHints     anchor_hints;
-  gint               rect_anchor_dx;
-  gint               rect_anchor_dy;
-  GdkWindowTypeHint  menu_type_hint;
-  gboolean           emulated_move_to_rect;
-
   guint toggle_size;
   guint accel_size;
 
@@ -81,9 +75,6 @@ struct _GtkMenuPrivate
   GdkWindow *view_window;
   GdkWindow *bin_window;
 
-  GtkCssGadget *top_arrow_gadget;
-  GtkCssGadget *bottom_arrow_gadget;
-
   gint scroll_offset;
   gint saved_scroll_offset;
   gint scroll_step;
@@ -141,14 +132,6 @@ struct _GtkMenuPrivate
   gint initial_drag_offset;
 };
 
-G_GNUC_INTERNAL
-void gtk_menu_update_scroll_offset (GtkMenu            *menu,
-                                    const GdkRectangle *flipped_rect,
-                                    const GdkRectangle *final_rect,
-                                    gboolean            flipped_x,
-                                    gboolean            flipped_y,
-                                    gpointer            user_data);
-
 G_END_DECLS
 
 #endif /* __GTK_MENU_PRIVATE_H__ */
