@@ -17,10 +17,10 @@
 
 /* This file implements most of the work of the ICCCM selection protocol.
  * The code was written after an intensive study of the equivalent part
- * of John Ousterhout’s Tk toolkit, and does many things in much the 
+ * of John Ousterhout's Tk toolkit, and does many things in much the 
  * same way.
  *
- * The one thing in the ICCCM that isn’t fully supported here (or in Tk)
+ * The one thing in the ICCCM that isn't fully supported here (or in Tk)
  * is side effects targets. For these to be handled properly, MULTIPLE
  * targets need to be done in the order specified. This cannot be
  * guaranteed with the way we do things, since if we are doing INCR
@@ -31,10 +31,10 @@
 
 /* Terminology note: when not otherwise specified, the term "incr" below
  * refers to the _sending_ part of the INCR protocol. The receiving
- * portion is referred to just as “retrieval”. (Terminology borrowed
- * from Tk, because there is no good opposite to “retrieval” in English.
- * “send” can’t be made into a noun gracefully and we’re already using
- * “emission” for something else ....)
+ * portion is referred to just as "retrieval". (Terminology borrowed
+ * from Tk, because there is no good opposite to "retrieval" in English.
+ * "send" can't be made into a noun gracefully and we're already using
+ * "emission" for something else ....)
  */
 
 /* The MOTIF entry widget seems to ask for the TARGETS target, then
@@ -66,25 +66,15 @@
  * never need to use most of the functions in this section directly;
  * #GtkClipboard provides a nicer interface to the same functionality.
  *
- * If an application is expected to exchange image data and work
- * on Windows, it is highly advised to support at least "image/bmp" target
- * for the widest possible compatibility with third-party applications.
- * #GtkClipboard already does that by using gtk_target_list_add_image_targets()
- * and gtk_selection_data_set_pixbuf() or gtk_selection_data_get_pixbuf(),
- * which is one of the reasons why it is advised to use #GtkClipboard.
- *
  * Some of the datatypes defined this section are used in
- * the #GtkClipboard and drag-and-drop API’s as well. The
- * #GtkTargetEntry and #GtkTargetList objects represent
+ * the #GtkClipboard and drag-and-drop API's as well. The
+ * #GtkTargetEntry structure and #GtkTargetList objects represent
  * lists of data types that are supported when sending or
  * receiving data. The #GtkSelectionData object is used to
  * store a chunk of data along with the data type and other
  * associated information.
  */
 
-/* We are using deprecated API, here, and we know that */
-#define GDK_DISABLE_DEPRECATION_WARNINGS
-
 #include "config.h"
 
 #include "gtkselection.h"
@@ -108,30 +98,16 @@
 #include "win32/gdkwin32.h"
 #endif
 
-#ifdef GDK_WINDOWING_WAYLAND
-#include <gdk/wayland/gdkwayland.h>
-#endif
-
-#ifdef GDK_WINDOWING_BROADWAY
-#include "broadway/gdkbroadway.h"
-#endif
-
-#ifndef G_OS_WIN32
-#include "filetransferportalprivate.h"
-#endif
-
 #undef DEBUG_SELECTION
 
 /* Maximum size of a sent chunk, in bytes. Also the default size of
    our buffers */
 #ifdef GDK_WINDOWING_X11
 #define GTK_SELECTION_MAX_SIZE(display)                                 \
-  GDK_IS_X11_DISPLAY (display) ?                                        \
   MIN(262144,                                                           \
       XExtendedMaxRequestSize (GDK_DISPLAY_XDISPLAY (display)) == 0     \
        ? XMaxRequestSize (GDK_DISPLAY_XDISPLAY (display)) - 100         \
-       : XExtendedMaxRequestSize (GDK_DISPLAY_XDISPLAY (display)) - 100)\
-  : G_MAXINT
+       : XExtendedMaxRequestSize (GDK_DISPLAY_XDISPLAY (display)) - 100)
 #else
 /* No chunks on Win32 */
 #define GTK_SELECTION_MAX_SIZE(display) G_MAXINT
@@ -238,13 +214,12 @@ static const char gtk_selection_handler_key[] = "gtk-selection-handlers";
 
 /**
  * gtk_target_list_new:
- * @targets: (array length=ntargets) (allow-none): Pointer to an array
- *   of #GtkTargetEntry
+ * @targets: (array length=ntargets): Pointer to an array of #GtkTargetEntry
  * @ntargets: number of entries in @targets.
  * 
  * Creates a new #GtkTargetList from an array of #GtkTargetEntry.
  * 
- * Returns: (transfer full): the new #GtkTargetList.
+ * Return value: (transfer full): the new #GtkTargetList.
  **/
 GtkTargetList *
 gtk_target_list_new (const GtkTargetEntry *targets,
@@ -266,7 +241,7 @@ gtk_target_list_new (const GtkTargetEntry *targets,
  * 
  * Increases the reference count of a #GtkTargetList by one.
  *
- * Returns: the passed in #GtkTargetList.
+ * Return value: the passed in #GtkTargetList.
  **/
 GtkTargetList *
 gtk_target_list_ref (GtkTargetList *list)
@@ -342,8 +317,6 @@ static GdkAtom text_plain_atom;
 static GdkAtom text_plain_utf8_atom;
 static GdkAtom text_plain_locale_atom;
 static GdkAtom text_uri_list_atom;
-static GdkAtom portal_files_atom;
-static GdkAtom portal_filetransfer_atom;
 
 static void 
 init_atoms (void)
@@ -364,8 +337,6 @@ init_atoms (void)
       g_free (tmp);
 
       text_uri_list_atom = gdk_atom_intern_static_string ("text/uri-list");
-      portal_files_atom = gdk_atom_intern_static_string ("application/vnd.portal.files");
-      portal_filetransfer_atom = gdk_atom_intern_static_string ("application/vnd.portal.filetransfer");
     }
 }
 
@@ -374,7 +345,7 @@ init_atoms (void)
  * @list: a #GtkTargetList
  * @info: an ID that will be passed back to the application
  * 
- * Appends the text targets supported by #GtkSelectionData to
+ * Appends the text targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
  * Since: 2.6
@@ -445,7 +416,7 @@ gtk_target_list_add_rich_text_targets (GtkTargetList  *list,
  * @writable: whether to add only targets for which GTK+ knows
  *   how to convert a pixbuf into the format
  * 
- * Appends the image targets supported by #GtkSelectionData to
+ * Appends the image targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
  * Since: 2.6
@@ -507,13 +478,9 @@ gtk_target_list_add_image_targets (GtkTargetList *list,
  * @list: a #GtkTargetList
  * @info: an ID that will be passed back to the application
  * 
- * Appends the URI targets supported by #GtkSelectionData to
+ * Appends the URI targets supported by #GtkSelection to
  * the target list. All targets are added with the same @info.
  * 
- * Since 3.24.37, this includes the application/vnd.portal.files
- * target when possible, to allow sending files between sandboxed
- * apps via the FileTransfer portal.
- *
  * Since: 2.6
  **/
 void 
@@ -524,15 +491,7 @@ gtk_target_list_add_uri_targets (GtkTargetList *list,
   
   init_atoms ();
 
-  gtk_target_list_add (list, text_uri_list_atom, 0, info);
-
-#ifndef G_OS_WIN32
-  if (file_transfer_portal_supported ())
-    {
-      gtk_target_list_add (list, portal_filetransfer_atom, 0, info);
-      gtk_target_list_add (list, portal_files_atom, 0, info);
-    }
-#endif
+  gtk_target_list_add (list, text_uri_list_atom, 0, info);  
 }
 
 /**
@@ -599,12 +558,12 @@ gtk_target_list_remove (GtkTargetList *list,
  * gtk_target_list_find:
  * @list: a #GtkTargetList
  * @target: an interned atom representing the target to search for
- * @info: (out) (allow-none): a pointer to the location to store
- *        application info for target, or %NULL
+ * @info: a pointer to the location to store application info for target,
+ *        or %NULL
  *
  * Looks up a given target in a #GtkTargetList.
  *
- * Returns: %TRUE if the target was found, otherwise %FALSE
+ * Return value: %TRUE if the target was found, otherwise %FALSE
  **/
 gboolean
 gtk_target_list_find (GtkTargetList *list,
@@ -644,7 +603,7 @@ gtk_target_list_find (GtkTargetList *list,
  * allocated and should be freed using gtk_target_table_free() when no
  * longer needed.
  *
- * Returns: (array length=n_targets) (transfer full): the new table.
+ * Return value: (array length=n_targets) (transfer full): the new table.
  *
  * Since: 2.10
  **/
@@ -662,7 +621,9 @@ gtk_target_table_new_from_list (GtkTargetList *list,
   *n_targets = g_list_length (list->list);
   targets = g_new0 (GtkTargetEntry, *n_targets);
 
-  for (tmp_list = list->list, i = 0; tmp_list; tmp_list = tmp_list->next, i++)
+  for (i = 0, tmp_list = list->list;
+       i < *n_targets;
+       i++, tmp_list = g_list_next (tmp_list))
     {
       GtkTargetPair *pair = tmp_list->data;
 
@@ -700,15 +661,15 @@ gtk_target_table_free (GtkTargetEntry *targets,
 
 /**
  * gtk_selection_owner_set_for_display:
- * @display: the #GdkDisplay where the selection is set
- * @widget: (allow-none): new selection owner (a #GtkWidget), or %NULL.
+ * @display: the #Gdkdisplay where the selection is set
+ * @widget: (allow-none): new selection owner (a #GdkWidget), or %NULL.
  * @selection: an interned atom representing the selection to claim.
  * @time_: timestamp with which to claim the selection
  *
  * Claim ownership of a given selection for a particular widget, or,
  * if @widget is %NULL, release ownership of the selection.
  *
- * Returns: TRUE if the operation succeeded 
+ * Return value: TRUE if the operation succeeded 
  * 
  * Since: 2.2
  */
@@ -810,7 +771,7 @@ gtk_selection_owner_set_for_display (GdkDisplay   *display,
  * Claims ownership of a given selection for a particular widget,
  * or, if @widget is %NULL, release ownership of the selection.
  * 
- * Returns: %TRUE if the operation succeeded
+ * Return value: %TRUE if the operation succeeded
  **/
 gboolean
 gtk_selection_owner_set (GtkWidget *widget,
@@ -915,15 +876,6 @@ gtk_selection_clear_targets (GtkWidget *widget,
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (selection != GDK_NONE);
 
-#ifdef GDK_WINDOWING_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gtk_widget_get_display (widget)))
-    gdk_wayland_selection_clear_targets (gtk_widget_get_display (widget), selection);
-#endif
-#ifdef GDK_WINDOWING_WIN32
-  if (GDK_IS_WIN32_DISPLAY (gtk_widget_get_display (widget)))
-    gdk_win32_selection_clear_targets (gtk_widget_get_display (widget), selection);
-#endif
-
   lists = g_object_get_data (G_OBJECT (widget), gtk_selection_handler_key);
   
   tmp_list = lists;
@@ -947,7 +899,7 @@ gtk_selection_clear_targets (GtkWidget *widget,
 
 /**
  * gtk_selection_add_target:
- * @widget:  a #GtkWidget
+ * @widget:  a #GtkTarget
  * @selection: the selection
  * @target: target to add.
  * @info: A unsigned integer which will be passed back to the application.
@@ -968,13 +920,8 @@ gtk_selection_add_target (GtkWidget	    *widget,
 
   list = gtk_selection_target_list_get (widget, selection);
   gtk_target_list_add (list, target, 0, info);
-#ifdef GDK_WINDOWING_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gtk_widget_get_display (widget)))
-    gdk_wayland_selection_add_targets (gtk_widget_get_window (widget), selection, 1, &target);
-#endif
 #ifdef GDK_WINDOWING_WIN32
-  if (GDK_IS_WIN32_DISPLAY (gtk_widget_get_display (widget)))
-    gdk_win32_selection_add_targets (gtk_widget_get_window (widget), selection, 1, &target);
+  gdk_win32_selection_add_targets (gtk_widget_get_window (widget), selection, 1, &target);
 #endif
 }
 
@@ -1003,31 +950,16 @@ gtk_selection_add_targets (GtkWidget            *widget,
   list = gtk_selection_target_list_get (widget, selection);
   gtk_target_list_add_table (list, targets, ntargets);
 
-#ifdef GDK_WINDOWING_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gtk_widget_get_display (widget)))
-    {
-      GdkAtom *atoms = g_new (GdkAtom, ntargets);
-      guint i;
-
-      for (i = 0; i < ntargets; i++)
-        atoms[i] = gdk_atom_intern (targets[i].target, FALSE);
-
-      gdk_wayland_selection_add_targets (gtk_widget_get_window (widget), selection, ntargets, atoms);
-      g_free (atoms);
-    }
-#endif
-
 #ifdef GDK_WINDOWING_WIN32
-  if (GDK_IS_WIN32_DISPLAY (gtk_widget_get_display (widget)))
-    {
-      int i;
-      GdkAtom *atoms = g_new (GdkAtom, ntargets);
+  {
+    int i;
+    GdkAtom *atoms = g_new (GdkAtom, ntargets);
 
-      for (i = 0; i < ntargets; ++i)
-        atoms[i] = gdk_atom_intern (targets[i].target, FALSE);
-      gdk_win32_selection_add_targets (gtk_widget_get_window (widget), selection, ntargets, atoms);
-      g_free (atoms);
-    }
+    for (i = 0; i < ntargets; ++i)
+      atoms[i] = gdk_atom_intern (targets[i].target, FALSE);
+    gdk_win32_selection_add_targets (gtk_widget_get_window (widget), selection, ntargets, atoms);
+    g_free (atoms);
+  }
 #endif
 }
 
@@ -1103,9 +1035,9 @@ gtk_selection_remove_all (GtkWidget *widget)
        In emergency, you could use #GDK_CURRENT_TIME
  * 
  * Requests the contents of a selection. When received, 
- * a “selection-received” signal will be generated.
+ * a "selection-received" signal will be generated.
  * 
- * Returns: %TRUE if requested succeeded. %FALSE if we could not process
+ * Return value: %TRUE if requested succeeded. %FALSE if we could not process
  *          request. (e.g., there was already a request in process for
  *          this widget).
  **/
@@ -1119,7 +1051,6 @@ gtk_selection_convert (GtkWidget *widget,
   GList *tmp_list;
   GdkWindow *owner_window;
   GdkDisplay *display;
-  guint id;
   
   g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
   g_return_val_if_fail (selection != GDK_NONE, FALSE);
@@ -1160,15 +1091,6 @@ gtk_selection_convert (GtkWidget *widget,
   display = gtk_widget_get_display (widget);
   owner_window = gdk_selection_owner_get_for_display (display, selection);
   
-#ifdef GDK_WINDOWING_WIN32
-  /* Special handling for DELETE requests,
-   * make sure this goes down into GDK layer.
-   */
-  if (GDK_IS_WIN32_DISPLAY (display) &&
-      target == gdk_atom_intern_static_string ("DELETE"))
-    owner_window = NULL;
-#endif
-
   if (owner_window != NULL)
     {
       GtkWidget *owner_widget;
@@ -1204,40 +1126,20 @@ gtk_selection_convert (GtkWidget *widget,
 	  return TRUE;
 	}
     }
-
-#if defined GDK_WINDOWING_BROADWAY
-  /* This patch is a workaround to circumvent unimplemented
-     clipboard functionality in broadwayd. It eliminates
-     35s delay on popup menu before first clipboard copy,
-     by preventing conversion to be started.
-   
-     https://gitlab.gnome.org/GNOME/gtk/issues/1630
-  */ 
-  if (GDK_IS_BROADWAY_DISPLAY (display))
-  {
-      g_debug("gtk_selection_convert: disabled for broadway backend");
-
-      gtk_selection_retrieval_report (
-          info, GDK_NONE, 0, NULL, -1, GDK_CURRENT_TIME);
-
-      return FALSE;
-  }
-#endif
   
   /* Otherwise, we need to go through X */
   
   current_retrievals = g_list_append (current_retrievals, info);
   gdk_selection_convert (gtk_widget_get_window (widget), selection, target, time_);
-  id = gdk_threads_add_timeout (1000,
+  gdk_threads_add_timeout (1000,
       (GSourceFunc) gtk_selection_retrieval_timeout, info);
-  g_source_set_name_by_id (id, "[gtk+] gtk_selection_retrieval_timeout");
   
   return TRUE;
 }
 
 /**
  * gtk_selection_data_get_selection:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the selection #GdkAtom of the selection data.
  *
@@ -1255,7 +1157,7 @@ gtk_selection_data_get_selection (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_get_target:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the target of the selection.
  *
@@ -1273,7 +1175,7 @@ gtk_selection_data_get_target (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_get_data_type:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the data type of the selection.
  *
@@ -1291,7 +1193,7 @@ gtk_selection_data_get_data_type (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_get_format:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the format of the selection.
  *
@@ -1309,12 +1211,11 @@ gtk_selection_data_get_format (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_get_data: (skip)
- * @selection_data: a pointer to a
- *   #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the raw data of the selection.
  *
- * Returns: (array) (element-type guint8): the raw data of the selection.
+ * Returns: the raw data of the selection.
  *
  * Since: 2.14
  **/
@@ -1328,7 +1229,7 @@ gtk_selection_data_get_data (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_get_length:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the length of the raw data of the selection.
  *
@@ -1345,14 +1246,15 @@ gtk_selection_data_get_length (const GtkSelectionData *selection_data)
 }
 
 /**
- * gtk_selection_data_get_data_with_length: (rename-to gtk_selection_data_get_data)
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * gtk_selection_data_get_data_with_length:
+ * @selection_data: a pointer to a #GtkSelectionData structure
  * @length: (out): return location for length of the data segment
  *
  * Retrieves the raw data of the selection along with its length.
  *
  * Returns: (array length=length): the raw data of the selection
  *
+ * Rename to: gtk_selection_data_get_data
  * Since: 3.0
  */
 const guchar*
@@ -1368,7 +1270,7 @@ gtk_selection_data_get_data_with_length (const GtkSelectionData *selection_data,
 
 /**
  * gtk_selection_data_get_display:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  *
  * Retrieves the display of the selection.
  *
@@ -1386,14 +1288,14 @@ gtk_selection_data_get_display (const GtkSelectionData *selection_data)
 
 /**
  * gtk_selection_data_set:
- * @selection_data: a pointer to a #GtkSelectionData-struct.
+ * @selection_data: a pointer to a #GtkSelectionData structure.
  * @type: the type of selection data
  * @format: format (number of bits in a unit)
  * @data: (array length=length): pointer to the data (will be copied)
  * @length: length of the data
  * 
  * Stores new data into a #GtkSelectionData object. Should
- * only be called from a selection handler callback.
+ * <emphasis>only</emphasis> be called from a selection handler callback.
  * Zero-terminates the stored data.
  **/
 void 
@@ -1456,15 +1358,14 @@ selection_set_compound_text (GtkSelectionData *selection_data,
 			     const gchar      *str,
 			     gint              len)
 {
-  gboolean result = FALSE;
-
-#ifdef GDK_WINDOWING_X11
   gchar *tmp;
   guchar *text;
   GdkAtom encoding;
   gint format;
   gint new_length;
+  gboolean result = FALSE;
 
+#ifdef GDK_WINDOWING_X11
   if (GDK_IS_X11_DISPLAY (selection_data->display))
     {
       tmp = g_strndup (str, len);
@@ -1642,7 +1543,7 @@ selection_get_text_plain (const GtkSelectionData *selection_data)
  * The string is converted to the form determined by
  * @selection_data->target.
  * 
- * Returns: %TRUE if the selection was successfully set,
+ * Return value: %TRUE if the selection was successfully set,
  *   otherwise %FALSE.
  **/
 gboolean
@@ -1692,7 +1593,7 @@ gtk_selection_data_set_text (GtkSelectionData     *selection_data,
  * 
  * Gets the contents of the selection data as a UTF-8 string.
  * 
- * Returns: (type utf8) (nullable) (transfer full): if the selection data contained a
+ * Return value: (type utf8): if the selection data contained a
  *   recognized text type and it could be converted to UTF-8, a newly
  *   allocated string containing the converted text, otherwise %NULL.
  *   If the result is non-%NULL it must be freed with g_free().
@@ -1746,7 +1647,7 @@ gtk_selection_data_get_text (const GtkSelectionData *selection_data)
  * The pixbuf is converted to the form determined by
  * @selection_data->target.
  * 
- * Returns: %TRUE if the selection was successfully set,
+ * Return value: %TRUE if the selection was successfully set,
  *   otherwise %FALSE.
  *
  * Since: 2.6
@@ -1810,11 +1711,10 @@ gtk_selection_data_set_pixbuf (GtkSelectionData *selection_data,
  * 
  * Gets the contents of the selection data as a #GdkPixbuf.
  * 
- * Returns: (nullable) (transfer full): if the selection data
- *   contained a recognized image type and it could be converted to a
- *   #GdkPixbuf, a newly allocated pixbuf is returned, otherwise
- *   %NULL.  If the result is non-%NULL it must be freed with
- *   g_object_unref().
+ * Return value: (transfer full): if the selection data contained a recognized
+ *   image type and it could be converted to a #GdkPixbuf, a 
+ *   newly allocated pixbuf is returned, otherwise %NULL.
+ *   If the result is non-%NULL it must be freed with g_object_unref().
  *
  * Since: 2.6
  **/
@@ -1855,11 +1755,8 @@ gtk_selection_data_get_pixbuf (const GtkSelectionData *selection_data)
  * Sets the contents of the selection from a list of URIs.
  * The string is converted to the form determined by
  * @selection_data->target.
- *
- * Since 3.24.37, this may involve using the FileTransfer
- * portal to send files between sandboxed apps.
  * 
- * Returns: %TRUE if the selection was successfully set,
+ * Return value: %TRUE if the selection was successfully set,
  *   otherwise %FALSE.
  *
  * Since: 2.6
@@ -1903,58 +1800,6 @@ gtk_selection_data_set_uris (GtkSelectionData  *selection_data,
 	  return TRUE;
 	}
     }
-#ifndef G_OS_WIN32
-  else if ((selection_data->target == portal_filetransfer_atom ||
-            selection_data->target == portal_files_atom) &&
-           file_transfer_portal_supported ())
-    {
-      GPtrArray *a;
-      char **files;
-      char *key;
-      GError *error = NULL;
-
-      a = g_ptr_array_new ();
-
-      for (int i = 0; uris[i]; i++)
-        {
-          GFile *file;
-          char *path;
-
-          file = g_file_new_for_uri (uris[i]);
-          path = g_file_get_path (file);
-          g_object_unref (file);
-
-          if (path == NULL)
-            {
-              g_ptr_array_unref (a);
-              return FALSE;
-            }
-
-          g_ptr_array_add (a, path);
-        }
-
-      g_ptr_array_add (a, NULL);
-      files = (char **) g_ptr_array_free (a, FALSE);
-
-      key = file_transfer_portal_register_files_sync ((const char **)files, TRUE, &error);
-      if (key == NULL)
-        {
-          g_strfreev (files);
-          g_warning ("%s", error->message);
-          g_error_free (error);
-          return FALSE;
-        }
-
-      gtk_selection_data_set (selection_data,
-                              selection_data->target,
-                              8, (guchar *)key, strlen (key));
-
-      g_strfreev (files);
-      g_free (key);
-
-      return TRUE;
-    }
-#endif
 
   return FALSE;
 }
@@ -1965,10 +1810,7 @@ gtk_selection_data_set_uris (GtkSelectionData  *selection_data,
  * 
  * Gets the contents of the selection data as array of URIs.
  *
- * Since 3.24.37, this may involve using the FileTransfer
- * portal to send files between sandboxed apps.
- *
- * Returns:  (array zero-terminated=1) (element-type utf8) (transfer full): if
+ * Return value:  (array zero-terminated=1) (element-type utf8) (transfer full): if
  *   the selection data contains a list of
  *   URIs, a newly allocated %NULL-terminated string array
  *   containing the URIs, otherwise %NULL. If the result is
@@ -2000,41 +1842,6 @@ gtk_selection_data_get_uris (const GtkSelectionData *selection_data)
       
       g_strfreev (list);
     }
-#ifndef G_OS_WIN32
-  else if (selection_data->length >= 0 &&
-           (selection_data->type == portal_filetransfer_atom ||
-            selection_data->type == portal_files_atom) &&
-           file_transfer_portal_supported ())
-    {
-      char *key;
-      GError *error = NULL;
-      char **files;
-
-      key = g_strndup ((char *) selection_data->data, selection_data->length);
-      files = file_transfer_portal_retrieve_files_sync (key, &error);
-      if (error)
-        {
-          g_warning ("%s", error->message);
-          g_error_free (error);
-        }
-      g_free (key);
-
-      if (files)
-        {
-          GPtrArray *uris = g_ptr_array_new ();
-
-          for (int i = 0; files[i]; i++)
-            {
-              GFile *file = g_file_new_for_path (files[i]);
-              g_ptr_array_add (uris, g_file_get_uri (file));
-              g_object_unref (file);
-            }
-
-          g_ptr_array_add (uris, NULL);
-          result = (char **) g_ptr_array_free (uris, FALSE);
-        }
-    }
-#endif
 
   return result;
 }
@@ -2053,7 +1860,7 @@ gtk_selection_data_get_uris (const GtkSelectionData *selection_data)
  * the standard TARGETS target that is always supplied for
  * any selection.
  * 
- * Returns: %TRUE if @selection_data contains a valid
+ * Return value: %TRUE if @selection_data contains a valid
  *    array of targets, otherwise %FALSE.
  **/
 gboolean
@@ -2087,13 +1894,13 @@ gtk_selection_data_get_targets (const GtkSelectionData  *selection_data,
 
 /**
  * gtk_targets_include_text:
- * @targets: (array length=n_targets): an array of #GdkAtoms
+ * @targets: (array length=n_targets): an array of #GdkAtom<!-- -->s
  * @n_targets: the length of @targets
  * 
  * Determines if any of the targets in @targets can be used to
  * provide text.
  * 
- * Returns: %TRUE if @targets include a suitable target for text,
+ * Return value: %TRUE if @targets include a suitable target for text,
  *   otherwise %FALSE.
  *
  * Since: 2.10
@@ -2132,14 +1939,14 @@ gtk_targets_include_text (GdkAtom *targets,
 
 /**
  * gtk_targets_include_rich_text:
- * @targets: (array length=n_targets): an array of #GdkAtoms
+ * @targets: (array length=n_targets): an array of #GdkAtom<!-- -->s
  * @n_targets: the length of @targets
  * @buffer: a #GtkTextBuffer
  *
  * Determines if any of the targets in @targets can be used to
  * provide rich text.
  *
- * Returns: %TRUE if @targets include a suitable target for rich text,
+ * Return value: %TRUE if @targets include a suitable target for rich text,
  *               otherwise %FALSE.
  *
  * Since: 2.10
@@ -2188,7 +1995,7 @@ gtk_targets_include_rich_text (GdkAtom       *targets,
  * determines if any of the targets in @targets can be used to
  * provide text.
  * 
- * Returns: %TRUE if @selection_data holds a list of targets,
+ * Return value: %TRUE if @selection_data holds a list of targets,
  *   and a suitable target for text is included, otherwise %FALSE.
  **/
 gboolean
@@ -2220,7 +2027,7 @@ gtk_selection_data_targets_include_text (const GtkSelectionData *selection_data)
  * determines if any of the targets in @targets can be used to
  * provide rich text.
  *
- * Returns: %TRUE if @selection_data holds a list of targets,
+ * Return value: %TRUE if @selection_data holds a list of targets,
  *               and a suitable target for rich text is included,
  *               otherwise %FALSE.
  *
@@ -2250,7 +2057,7 @@ gtk_selection_data_targets_include_rich_text (const GtkSelectionData *selection_
 
 /**
  * gtk_targets_include_image:
- * @targets: (array length=n_targets): an array of #GdkAtoms
+ * @targets: (array length=n_targets): an array of #GdkAtom<!-- -->s
  * @n_targets: the length of @targets
  * @writable: whether to accept only targets for which GTK+ knows
  *   how to convert a pixbuf into the format
@@ -2258,7 +2065,7 @@ gtk_selection_data_targets_include_rich_text (const GtkSelectionData *selection_
  * Determines if any of the targets in @targets can be used to
  * provide a #GdkPixbuf.
  * 
- * Returns: %TRUE if @targets include a suitable target for images,
+ * Return value: %TRUE if @targets include a suitable target for images,
  *   otherwise %FALSE.
  *
  * Since: 2.10
@@ -2304,7 +2111,7 @@ gtk_targets_include_image (GdkAtom *targets,
  * determines if any of the targets in @targets can be used to
  * provide a #GdkPixbuf.
  * 
- * Returns: %TRUE if @selection_data holds a list of targets,
+ * Return value: %TRUE if @selection_data holds a list of targets,
  *   and a suitable target for images is included, otherwise %FALSE.
  *
  * Since: 2.6
@@ -2332,13 +2139,13 @@ gtk_selection_data_targets_include_image (const GtkSelectionData *selection_data
 
 /**
  * gtk_targets_include_uri:
- * @targets: (array length=n_targets): an array of #GdkAtoms
+ * @targets: (array length=n_targets): an array of #GdkAtom<!-- -->s
  * @n_targets: the length of @targets
  * 
  * Determines if any of the targets in @targets can be used to
  * provide an uri list.
  * 
- * Returns: %TRUE if @targets include a suitable target for uri lists,
+ * Return value: %TRUE if @targets include a suitable target for uri lists,
  *   otherwise %FALSE.
  *
  * Since: 2.10
@@ -2359,9 +2166,7 @@ gtk_targets_include_uri (GdkAtom *targets,
 
   for (i = 0; i < n_targets; i++)
     {
-      if (targets[i] == text_uri_list_atom ||
-          targets[i] == portal_filetransfer_atom ||
-          targets[i] == portal_files_atom)
+      if (targets[i] == text_uri_list_atom)
 	{
 	  result = TRUE;
 	  break;
@@ -2379,7 +2184,7 @@ gtk_targets_include_uri (GdkAtom *targets,
  * determines if any of the targets in @targets can be used to
  * provide a list or URIs.
  * 
- * Returns: %TRUE if @selection_data holds a list of targets,
+ * Return value: %TRUE if @selection_data holds a list of targets,
  *   and a suitable target for URI lists is included, otherwise %FALSE.
  *
  * Since: 2.10
@@ -2433,7 +2238,7 @@ gtk_selection_init (void)
  * The default handler for the #GtkWidget::selection-clear-event
  * signal. 
  * 
- * Returns: %TRUE if the event was handled, otherwise false
+ * Return value: %TRUE if the event was handled, otherwise false
  **/
 gboolean
 _gtk_selection_clear (GtkWidget         *widget,
@@ -2471,7 +2276,7 @@ _gtk_selection_clear (GtkWidget         *widget,
 
 /*************************************************************
  * _gtk_selection_request:
- *     Handler for “selection_request_event” 
+ *     Handler for "selection_request_event" 
  *   arguments:
  *     widget:
  *     event:
@@ -2488,9 +2293,6 @@ _gtk_selection_request (GtkWidget *widget,
   int i;
   gulong selection_max_size;
 
-  if (event->requestor == NULL)
-    return FALSE;
-
   if (initialize)
     gtk_selection_init ();
   
@@ -2637,27 +2439,23 @@ _gtk_selection_request (GtkWidget *widget,
 	  info->conversions[i].data = data;
 	  info->num_incrs++;
 	  
-	  gdk_error_trap_push ();
 	  gdk_property_change (info->requestor, 
 			       info->conversions[i].property,
 			       gtk_selection_atoms[INCR],
 			       32,
 			       GDK_PROP_MODE_REPLACE,
 			       (guchar *)&items, 1);
-	  gdk_error_trap_pop_ignored ();
 	}
       else
 	{
 	  info->conversions[i].offset = -1;
 	  
-	  gdk_error_trap_push ();
 	  gdk_property_change (info->requestor, 
 			       info->conversions[i].property,
 			       data.type,
 			       data.format,
 			       GDK_PROP_MODE_REPLACE,
 			       data.data, items);
-	  gdk_error_trap_pop_ignored ();
 	  
 	  g_free (data.data);
 	}
@@ -2668,8 +2466,6 @@ _gtk_selection_request (GtkWidget *widget,
   
   if (info->num_incrs > 0)
     {
-      guint id;
-
       /* FIXME: this could be dangerous if window doesn't still
 	 exist */
       
@@ -2677,14 +2473,11 @@ _gtk_selection_request (GtkWidget *widget,
       g_message ("Starting INCR...");
 #endif
       
-      gdk_error_trap_push ();
       gdk_window_set_events (info->requestor,
 			     gdk_window_get_events (info->requestor) |
 			     GDK_PROPERTY_CHANGE_MASK);
-      gdk_error_trap_pop_ignored ();
       current_incrs = g_list_append (current_incrs, info);
-      id = gdk_threads_add_timeout (1000, (GSourceFunc) gtk_selection_incr_timeout, info);
-      g_source_set_name_by_id (id, "[gtk+] gtk_selection_incr_timeout");
+      gdk_threads_add_timeout (1000, (GSourceFunc) gtk_selection_incr_timeout, info);
     }
   
   /* If it was a MULTIPLE request, set the property to indicate which
@@ -2697,13 +2490,11 @@ _gtk_selection_request (GtkWidget *widget,
 	  mult_atoms[2*i] = info->conversions[i].target;
 	  mult_atoms[2*i+1] = info->conversions[i].property;
 	}
-
-      gdk_error_trap_push ();
+      
       gdk_property_change (info->requestor, event->property,
 			   gdk_atom_intern_static_string ("ATOM_PAIR"), 32, 
 			   GDK_PROP_MODE_REPLACE,
 			   (guchar *)mult_atoms, 2*info->num_conversions);
-      gdk_error_trap_pop_ignored ();
       g_free (mult_atoms);
     }
 
@@ -2827,14 +2618,12 @@ _gtk_selection_incr_event (GdkWindow	   *window,
 #endif
 
 	  bytes_per_item = gtk_selection_bytes_per_item (info->conversions[i].data.format);
-	  gdk_error_trap_push ();
 	  gdk_property_change (info->requestor, event->atom,
 			       info->conversions[i].data.type,
 			       info->conversions[i].data.format,
 			       GDK_PROP_MODE_REPLACE,
 			       buffer,
 			       num_bytes / bytes_per_item);
-	  gdk_error_trap_pop_ignored ();
 	  
 	  if (info->conversions[i].offset == -2)
 	    {
@@ -2917,7 +2706,7 @@ gtk_selection_incr_timeout (GtkIncrInfo *info)
 
 /*************************************************************
  * _gtk_selection_notify:
- *     Handler for “selection-notify-event” signals on windows
+ *     Handler for "selection-notify-event" signals on windows
  *     where a retrieval is currently in process. The selection
  *     owner has responded to our conversion request.
  *   arguments:
@@ -3009,7 +2798,7 @@ _gtk_selection_notify (GtkWidget	 *widget,
 
 /*************************************************************
  * _gtk_selection_property_notify:
- *     Handler for “property-notify-event” signals on windows
+ *     Handler for "property-notify-event" signals on windows
  *     where a retrieval is currently in process. The selection
  *     owner has added more data.
  *   arguments:
@@ -3166,7 +2955,7 @@ gtk_selection_retrieval_timeout (GtkRetrievalInfo *info)
 
 /*************************************************************
  * gtk_selection_retrieval_report:
- *     Emits a “selection-received” signal.
+ *     Emits a "selection-received" signal.
  *   arguments:
  *     info:	  information about the retrieval that completed
  *     buffer:	  buffer containing data (NULL => errror)
@@ -3239,8 +3028,8 @@ gtk_selection_invoke_handler (GtkWidget	       *widget,
 /*************************************************************
  * gtk_selection_default_handler:
  *     Handles some default targets that exist for any widget
- *     If it can’t fit results into buffer, returns -1. This
- *     won’t happen in any conceivable case, since it would
+ *     If it can't fit results into buffer, returns -1. This
+ *     won't happen in any conceivable case, since it would
  *     require 1000 selection targets!
  *
  *   arguments:
@@ -3332,11 +3121,11 @@ gtk_selection_default_handler (GtkWidget	*widget,
 
 /**
  * gtk_selection_data_copy:
- * @data: a pointer to a #GtkSelectionData-struct.
+ * @data: a pointer to a #GtkSelectionData structure.
  * 
- * Makes a copy of a #GtkSelectionData-struct and its data.
+ * Makes a copy of a #GtkSelectionData structure and its data.
  * 
- * Returns: a pointer to a copy of @data.
+ * Return value: a pointer to a copy of @data.
  **/
 GtkSelectionData*
 gtk_selection_data_copy (const GtkSelectionData *data)
@@ -3359,9 +3148,9 @@ gtk_selection_data_copy (const GtkSelectionData *data)
 
 /**
  * gtk_selection_data_free:
- * @data: a pointer to a #GtkSelectionData-struct.
+ * @data: a pointer to a #GtkSelectionData structure.
  * 
- * Frees a #GtkSelectionData-struct returned from
+ * Frees a #GtkSelectionData structure returned from
  * gtk_selection_data_copy().
  **/
 void
@@ -3380,9 +3169,9 @@ gtk_selection_data_free (GtkSelectionData *data)
  * @flags: Set of flags, see #GtkTargetFlags
  * @info: an ID that will be passed back to the application
  *
- * Makes a new #GtkTargetEntry.
+ * Makes a new #GtkTargetEntry structure.
  *
- * Returns: a pointer to a new #GtkTargetEntry.
+ * Return value: a pointer to a new GtkTargetEntry structure.
  *     Free with gtk_target_entry_free()
  **/
 GtkTargetEntry *
@@ -3396,11 +3185,11 @@ gtk_target_entry_new (const char *target,
 
 /**
  * gtk_target_entry_copy:
- * @data: a pointer to a #GtkTargetEntry
+ * @data: a pointer to a #GtkTargetEntry structure.
  *
- * Makes a copy of a #GtkTargetEntry and its data.
+ * Makes a copy of a #GtkTargetEntry structure and its data.
  *
- * Returns: a pointer to a copy of @data.
+ * Return value: a pointer to a copy of @data.
  *     Free with gtk_target_entry_free()
  **/
 GtkTargetEntry *
@@ -3420,9 +3209,9 @@ gtk_target_entry_copy (GtkTargetEntry *data)
 
 /**
  * gtk_target_entry_free:
- * @data: a pointer to a #GtkTargetEntry.
+ * @data: a pointer to a #GtkTargetEntry structure.
  *
- * Frees a #GtkTargetEntry returned from
+ * Frees a #GtkTargetEntry structure returned from
  * gtk_target_entry_new() or gtk_target_entry_copy().
  **/
 void
