@@ -15,9 +15,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -134,21 +132,16 @@ append_error_value (GString *string,
 
 static void
 parsing_error_cb (GtkCssProvider *provider,
-                  const gchar     *path,
-                  guint            line,
-                  guint            position,
-                  const GError *   error,
-                  GString *        errors)
+                  GtkCssSection  *section,
+                  const GError   *error,
+                  GString        *errors)
 {
   char *basename;
 
-  g_assert (path);
-  g_assert (line > 0);
-
-  basename = g_path_get_basename (path);
+  basename = g_file_get_basename (gtk_css_section_get_file (section));
   g_string_append_printf (errors,
                           "%s:%u: error: ",
-                          basename, line);
+                          basename, gtk_css_section_get_end_line (section) + 1);
   g_free (basename);
                           
   if (error->domain == GTK_CSS_PROVIDER_ERROR)
