@@ -103,36 +103,15 @@ on_notebook_drag_begin (GtkWidget      *widget,
 
   if (page_num > 2)
     {
-      GtkIconTheme *icon_theme;
-      int width;
-
-      icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
-      gtk_icon_size_lookup (GTK_ICON_SIZE_DND, &width, NULL);
-      pixbuf = gtk_icon_theme_load_icon (icon_theme,
-                                         (page_num % 2) ? "help-browser" : "process-stop",
-                                         width,
-                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK,
-                                         NULL);
+      pixbuf = gtk_widget_render_icon_pixbuf (widget,
+                                              (page_num % 2) ? GTK_STOCK_HELP : GTK_STOCK_STOP,
+                                              GTK_ICON_SIZE_DND);
 
       gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
       g_object_unref (pixbuf);
     }
 }
 
-static gboolean
-remove_in_idle (gpointer data)
-{
-  GtkWidget *child = data;
-  GtkWidget *parent = gtk_widget_get_parent (child);
-  GtkWidget *tab_label;
-
-  tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (parent), child);
-  g_print ("Removing tab: %s\n", gtk_label_get_text (GTK_LABEL (tab_label)));
-  gtk_container_remove (GTK_CONTAINER (parent), child);
-
-  return G_SOURCE_REMOVE;
-}
-
 static void
 on_button_drag_data_received (GtkWidget        *widget,
                               GdkDragContext   *context,
@@ -143,11 +122,16 @@ on_button_drag_data_received (GtkWidget        *widget,
                               guint             time,
                               gpointer          user_data)
 {
+  GtkWidget *source, *tab_label;
   GtkWidget **child;
 
+  source = gtk_drag_get_source_widget (context);
   child = (void*) gtk_selection_data_get_data (data);
 
-  g_idle_add (remove_in_idle, *child);
+  tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (source), *child);
+  g_print ("Removing tab: %s\n", gtk_label_get_text (GTK_LABEL (tab_label)));
+
+  gtk_container_remove (GTK_CONTAINER (source), *child);
 }
 
 static GtkWidget*
@@ -235,7 +219,7 @@ create_trash_button (void)
 {
   GtkWidget *button;
 
-  button = gtk_button_new_with_mnemonic ("_Delete");
+  button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
 
   gtk_drag_dest_set (button,
                      GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_DROP,
